@@ -16,6 +16,7 @@ from fieldpy.primitives import axis
 from fieldpy.primitives import grid
 from fieldpy.primitives import idx
 
+
 class datafield2D(object):
     r"""A container class for a datafield arranged on a rectilinear grid
 
@@ -72,12 +73,14 @@ class datafield2D(object):
 
         if self.mode == "center":
             if not (
-                self.dataGrid.NOC_X, self.dataGrid.NOC_Y) == dataArray.shape:
+                    self.dataGrid.NOC_X,
+                    self.dataGrid.NOC_Y) == dataArray.shape:
                 raise ValueError(
                     "The 'dataGrid' and 'dataArray' dimensions do not match")
         elif self.mode == "node":
             if not (
-                self.dataGrid.NOE_X, self.dataGrid.NOE_Y) == dataArray.shape:
+                    self.dataGrid.NOE_X,
+                    self.dataGrid.NOE_Y) == dataArray.shape:
                 raise ValueError(
                     "The 'dataGrid' and 'dataArray' dimensions do not match")
         else:
@@ -94,7 +97,7 @@ class datafield2D(object):
             idxMax (idx.idx2D): The 2D index of the maximum in 'dataArray'
         """
 
-        #use numpy to find the max element and then unravel that 1D index into
+        # use numpy to find the max element and then unravel that 1D index into
         #a 2D index
         inds = numpy.unravel_index(self.dataArray.argmax(),
                                    self.dataArray.shape)
@@ -141,7 +144,7 @@ class datafield2D(object):
                 coordinates the grid is shifted by
         """
 
-        #shift 'dataGrid'
+        # shift 'dataGrid'
         self.dataGrid.shiftGrid(coordsShift)
 
     def shiftToOrigin(self, coordsFrom=None):
@@ -167,8 +170,8 @@ class datafield2D(object):
         else:
             coordsFrom = point.pointCart2D(coordsFrom)
 
-        #shift 'dataGrid'
-        self.dataGrid.shiftGrid(coordsFrom*(-1.0))
+        # shift 'dataGrid'
+        self.dataGrid.shiftGrid(coordsFrom * (-1.0))
 
     def scaleData(self, factor):
         r"""Scales the 'dataArray' by a given 'factor'
@@ -221,7 +224,7 @@ class datafield2D(object):
             datafield_new (datafield.datafield2D): The new datafield
         """
 
-        #convert the given coordinates
+        # convert the given coordinates
         coordsStart = point.pointCart2D(coordsStart)
         coordsStop = point.pointCart2D(coordsStop)
 
@@ -232,7 +235,7 @@ class datafield2D(object):
         #create a new grid and data array
         grid_new = self.dataGrid.createSubset(coordsStart, coordsStop)
         array_new = self.dataArray[idxStart.i:idxStop.i + 1,
-                                   idxStart.j:idxStop.j + 1]
+                    idxStart.j:idxStop.j + 1]
 
         #create a new deep-copied datafield
         datafield_new = datafield2D(grid_new,
@@ -275,7 +278,7 @@ class datafield2D(object):
 
         return datafield_new
 
-    def _toHDF5(self, fname):
+    def _toHDF5(self, fname, useCompression=True):
         r"""Saves the dataset to an HDF5 file
 
         This method creates an .h5 file under 'fname' and saves the contents of
@@ -291,15 +294,21 @@ class datafield2D(object):
         # write axes edge coordinate (in order to later recreate it)
         fid.create_dataset(name="axis_x",
                            shape=self.dataGrid.axis_x.coordsEdges.shape,
-                           data=self.dataGrid.axis_x.coordsEdges)
+                           data=self.dataGrid.axis_x.coordsEdges,
+                           compression="gzip" if useCompression else None,
+                           compression_opts=9 if useCompression else None)
         fid.create_dataset(name="axis_y",
                            shape=self.dataGrid.axis_y.coordsEdges.shape,
-                           data=self.dataGrid.axis_y.coordsEdges)
+                           data=self.dataGrid.axis_y.coordsEdges,
+                           compression="gzip" if useCompression else None,
+                           compression_opts=9 if useCompression else None)
 
         # write dataArray
         dset = fid.create_dataset(name="dataArray",
                                   shape=self.dataArray.shape,
-                                  data=self.dataArray)
+                                  data=self.dataArray,
+                                  compression="gzip" if useCompression else None,
+                                  compression_opts=9 if useCompression else None)
         # write datafield mode as an attribute of the dataArray dataset
         dset.attrs["mode"] = self.mode
 
@@ -356,7 +365,7 @@ class datafield2D(object):
                        spacing,
                        offset)
 
-    def toFile(self, fname):
+    def toFile(self, fname, useCompression=True):
         r"""Saves the dataset to a file
 
         This method saves the necessary contents of the dataset in order to
@@ -373,6 +382,8 @@ class datafield2D(object):
 
         Parameters:
             fname (str): The filename under which the dataset is saved
+            useCompression (bool): Whether to use compression or not, when
+                supported
         """
 
         # get the file extension
@@ -381,7 +392,7 @@ class datafield2D(object):
 
         # check the format and call the appropriate private method
         if strFormat == ".h5":
-            self._toHDF5(fname)
+            self._toHDF5(fname, useCompression)
         elif strFormat == ".mat":
             self._toMat(fname)
         elif strFormat == ".mhd":
@@ -414,6 +425,11 @@ class datafield2D(object):
         dataArray = numpy.array(fid['dataArray'])
         mode = str(fid['dataArray'].attrs["mode"])
 
+        if "node" in mode:
+            mode = "node"
+        elif "center" in mode:
+            mode = "center"
+
         # create a new datafield with the loaded data
         df = cls(grid.grid2D(axis_x,
                              axis_y),
@@ -421,7 +437,7 @@ class datafield2D(object):
                  mode,
                  deepCopy=True)
 
-        #close the file
+        # close the file
         fid.close()
 
         return df
@@ -448,9 +464,7 @@ class datafield2D(object):
         dataArray = numpy.array(data['dataArray'])
 
         # recreate mode string
-        mode = str(data['mode'])
-        mode = mode.replace("[u'", "") #clean junk
-        mode = mode.replace("']", "")
+        mode = str(data['mode'][0])
 
         # create new datafield object
         df = cls(grid.grid2D(axis_x,
@@ -607,7 +621,7 @@ class datafield3D(object):
             idxMax (idx.idx3D): The 3D index of the maximum in 'dataArray'
         """
 
-        #use numpy to find the max element and then unravel that 1D index into
+        # use numpy to find the max element and then unravel that 1D index into
         #a 3D index
         inds = numpy.unravel_index(self.dataArray.argmax(),
                                    self.dataArray.shape)
@@ -654,7 +668,7 @@ class datafield3D(object):
                 coordinates the grid is shifted by
         """
 
-        #shift 'dataGrid'
+        # shift 'dataGrid'
         self.dataGrid.shiftGrid(coordsShift)
 
     def shiftToOrigin(self, coordsFrom=None):
@@ -680,8 +694,8 @@ class datafield3D(object):
         else:
             coordsFrom = point.pointCart3D(coordsFrom)
 
-        #shift 'dataGrid'
-        self.dataGrid.shiftGrid(coordsFrom*(-1.0))
+        # shift 'dataGrid'
+        self.dataGrid.shiftGrid(coordsFrom * (-1.0))
 
     def scaleData(self, factor):
         r"""Scales the 'dataArray' by a given 'factor'
@@ -734,7 +748,7 @@ class datafield3D(object):
             datafield_new (datafield.datafield3D): The new datafield
         """
 
-        #convert the given coordinates
+        # convert the given coordinates
         coordsStart = point.pointCart3D(coordsStart)
         coordsStop = point.pointCart3D(coordsStop)
 
@@ -745,8 +759,8 @@ class datafield3D(object):
         #create a new grid and data array
         grid_new = self.dataGrid.createSubset(coordsStart, coordsStop)
         array_new = self.dataArray[idxStart.i:idxStop.i + 1,
-                                   idxStart.j:idxStop.j + 1,
-                                   idxStart.k:idxStop.k + 1]
+                    idxStart.j:idxStop.j + 1,
+                    idxStart.k:idxStop.k + 1]
 
         #create a new deep-copied datafield
         datafield_new = datafield3D(grid_new,
@@ -771,7 +785,7 @@ class datafield3D(object):
                 datafield
         """
 
-        #check that the mode of the current field is indeed nodal
+        # check that the mode of the current field is indeed nodal
         if self.mode != "node":
             raise ValueError(
                 "The current datafield is not in 'node' mode. This method "
@@ -789,7 +803,7 @@ class datafield3D(object):
 
         return datafield_new
 
-    def _toHDF5(self, fname):
+    def _toHDF5(self, fname, useCompression=True):
         r"""Saves the dataset to an HDF5 file
 
         This method creates an .h5 file under 'fname' and saves the contents of
@@ -805,18 +819,26 @@ class datafield3D(object):
         # write axes edge coordinate (in order to later recreate it)
         fid.create_dataset(name="axis_x",
                            shape=self.dataGrid.axis_x.coordsEdges.shape,
-                           data=self.dataGrid.axis_x.coordsEdges)
+                           data=self.dataGrid.axis_x.coordsEdges,
+                           compression="gzip" if useCompression else None,
+                           compression_opts=9 if useCompression else None)
         fid.create_dataset(name="axis_y",
                            shape=self.dataGrid.axis_y.coordsEdges.shape,
-                           data=self.dataGrid.axis_y.coordsEdges)
+                           data=self.dataGrid.axis_y.coordsEdges,
+                           compression="gzip" if useCompression else None,
+                           compression_opts=9 if useCompression else None)
         fid.create_dataset(name="axis_z",
                            shape=self.dataGrid.axis_z.coordsEdges.shape,
-                           data=self.dataGrid.axis_z.coordsEdges)
+                           data=self.dataGrid.axis_z.coordsEdges,
+                           compression="gzip" if useCompression else None,
+                           compression_opts=9 if useCompression else None)
 
         # write dataArray
         dset = fid.create_dataset(name="dataArray",
                                   shape=self.dataArray.shape,
-                                  data=self.dataArray)
+                                  data=self.dataArray,
+                                  compression="gzip" if useCompression else None,
+                                  compression_opts=9 if useCompression else None)
         # write datafield mode as an attribute of the dataArray dataset
         dset.attrs["mode"] = self.mode
 
@@ -876,7 +898,7 @@ class datafield3D(object):
                        spacing,
                        offset)
 
-    def toFile(self, fname):
+    def toFile(self, fname, useCompression=True):
         r"""Saves the dataset to a file
 
         This method saves the necessary contents of the dataset in order to
@@ -893,6 +915,8 @@ class datafield3D(object):
 
         Parameters:
             fname (str): The filename under which the dataset is saved
+            useCompression (bool): Whether to use compression or not, when
+                supported
         """
 
         # get the file extension
@@ -901,7 +925,7 @@ class datafield3D(object):
 
         # check the format and call the appropriate private method
         if strFormat == ".h5":
-            self._toHDF5(fname)
+            self._toHDF5(fname, useCompression)
         elif strFormat == ".mat":
             self._toMat(fname)
         elif strFormat == ".mhd":
@@ -935,6 +959,11 @@ class datafield3D(object):
         dataArray = numpy.array(fid['dataArray'])
         mode = str(fid['dataArray'].attrs["mode"])
 
+        if "node" in mode:
+            mode = "node"
+        elif "center" in mode:
+            mode = "center"
+
         # create a new datafield with the loaded data
         df = cls(grid.grid3D(axis_x,
                              axis_y,
@@ -943,7 +972,7 @@ class datafield3D(object):
                  mode,
                  deepCopy=True)
 
-        #close the file
+        # close the file
         fid.close()
 
         return df
@@ -971,9 +1000,7 @@ class datafield3D(object):
         dataArray = numpy.array(data['dataArray'])
 
         # recreate mode string
-        mode = str(data['mode'])
-        mode = mode.replace("[u'", "") #clean junk
-        mode = mode.replace("']", "")
+        mode = str(data['mode'][0])
 
         # create new datafield object
         df = cls(grid.grid3D(axis_x,
