@@ -136,9 +136,30 @@ class pointCart3D(object):
 			return pointCart3D([self.x * other, self.y * other, self.z * other])
 		else:
 			raise TypeError("Can't multiply '" + str(other) + "' and '" + str(self) + "'")
-		
+
 	def __div__(self, other):
 		r"""Division overloader (multiple 'type' support)
+
+		This method overloads the '/' operator and allows for the coordinates of
+		a 'pointCart3D' object to be divided with either those of another object
+		of the same type or with a list, a tuple, or even with a single float
+
+		Parameters:
+			other (pointCart3D, list, tuple, or float): Another 'pointCart3D'
+				object, a list/tuple with (at least) 3 values, or a single float
+		"""
+
+		if type(self) == type(other):
+			return pointCart3D([self.x / other.x, self.y / other.y, self.z / other.z])
+		elif (type(other) == list) or (type(other) == tuple):
+			return pointCart3D([self.x / other[0], self.y / other[1], self.z / other[2]])
+		elif numpy.isreal(other):
+			return pointCart3D([self.x / other, self.y / other, self.z / other])
+		else:
+			raise TypeError("Can't divide '" + str(other) + "' and '" + str(self) + "'")
+
+	def __truediv__(self, other):
+		r"""Division overloader (multiple 'type' support)
 		
 		This method overloads the '/' operator and allows for the coordinates of
 		a 'pointCart3D' object to be divided with either those of another object
@@ -157,7 +178,28 @@ class pointCart3D(object):
 			return pointCart3D([self.x / other, self.y / other, self.z / other])
 		else:
 			raise TypeError("Can't divide '" + str(other) + "' and '" + str(self) + "'")
-	
+
+	def __floordiv__(self, other):
+		r"""Division overloader (multiple 'type' support)
+
+		This method overloads the '/' operator and allows for the coordinates of
+		a 'pointCart3D' object to be divided with either those of another object
+		of the same type or with a list, a tuple, or even with a single float
+
+		Parameters:
+			other (pointCart3D, list, tuple, or float): Another 'pointCart3D'
+				object, a list/tuple with (at least) 3 values, or a single float
+		"""
+
+		if type(self) == type(other):
+			return pointCart3D([self.x // other.x, self.y // other.y, self.z // other.z])
+		elif (type(other) == list) or (type(other) == tuple):
+			return pointCart3D([self.x // other[0], self.y // other[1], self.z // other[2]])
+		elif numpy.isreal(other):
+			return pointCart3D([self.x // other, self.y // other, self.z // other])
+		else:
+			raise TypeError("Can't divide '" + str(other) + "' and '" + str(self) + "'")
+
 	def __abs__(self):
 		r"""Returns the mangitude of the point as if it was a vector
 		
@@ -401,7 +443,49 @@ class pointCart2D(object):
 			return pointCart2D([self.x / other, self.y / other])
 		else:
 			raise TypeError("Can't divide '" + str(other) + "' and '" + str(self) + "'")
-	
+
+	def __truediv__(self, other):
+		r"""Division overloader (multiple 'type' support)
+
+		This method overloads the '/' operator and allows for the coordinates of
+		a 'pointCart2D' object to be divided with either those of another object
+		of the same type or with a list, a tuple, or even with a single float
+
+		Parameters:
+			other (pointCart2D, list, tuple, or float): Another 'pointCart3D'
+				object, a list/tuple with (at least) 2 values, or a single float
+		"""
+
+		if type(self) == type(other):
+			return pointCart2D([self.x / other.x, self.y / other.y])
+		elif (type(other) == list) or (type(other) == tuple):
+			return pointCart2D([self.x / other[0], self.y / other[1]])
+		elif numpy.isreal(other):
+			return pointCart2D([self.x / other, self.y / other])
+		else:
+			raise TypeError("Can't divide '" + str(other) + "' and '" + str(self) + "'")
+
+	def __floordiv__(self, other):
+		r"""Division overloader (multiple 'type' support)
+
+		This method overloads the '/' operator and allows for the coordinates of
+		a 'pointCart2D' object to be divided with either those of another object
+		of the same type or with a list, a tuple, or even with a single float
+
+		Parameters:
+			other (pointCart2D, list, tuple, or float): Another 'pointCart3D'
+				object, a list/tuple with (at least) 2 values, or a single float
+		"""
+
+		if type(self) == type(other):
+			return pointCart2D([self.x // other.x, self.y // other.y])
+		elif (type(other) == list) or (type(other) == tuple):
+			return pointCart2D([self.x // other[0], self.y // other[1]])
+		elif numpy.isreal(other):
+			return pointCart2D([self.x // other, self.y // other])
+		else:
+			raise TypeError("Can't divide '" + str(other) + "' and '" + str(self) + "'")
+
 	def __abs__(self):
 		r"""Returns the mangitude of the point as if it was a vector
 		
