@@ -10,9 +10,11 @@ def runTests():
     # Change current working directory to 'cfd'
     os.chdir(cfd)
     # Run all tests
-    nose.run(argv = [cfd,"--verbosity=2"])
+    result = nose.run(argv = [cfd,"--verbosity=2"])
     # Change current working directory to its previous state
     os.chdir(cwd)
 
+    return result
+
 if __name__ == "__main__":
     runTests()
